@@ -3,15 +3,27 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.ExchangeVoucherModify import ExchangeVoucherModify
 from alipay.aop.api.domain.VoucherValidPeriodModify import VoucherValidPeriodModify
 
 
 class VoucherUseRuleModify(object):
 
     def __init__(self):
+        self._exchange_voucher = None
         self._voucher_valid_period = None
 
     @property
+    def exchange_voucher(self):
+        return self._exchange_voucher
+
+    @exchange_voucher.setter
+    def exchange_voucher(self, value):
+        if isinstance(value, ExchangeVoucherModify):
+            self._exchange_voucher = value
+        else:
+            self._exchange_voucher = ExchangeVoucherModify.from_alipay_dict(value)
+    @property
     def voucher_valid_period(self):
         return self._voucher_valid_period
 
@@ -25,6 +37,11 @@ class VoucherUseRuleModify(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.exchange_voucher:
+            if hasattr(self.exchange_voucher, 'to_alipay_dict'):
+                params['exchange_voucher'] = self.exchange_voucher.to_alipay_dict()
+            else:
+                params['exchange_voucher'] = self.exchange_voucher
         if self.voucher_valid_period:
             if hasattr(self.voucher_valid_period, 'to_alipay_dict'):
                 params['voucher_valid_period'] = self.voucher_valid_period.to_alipay_dict()
@@ -37,6 +54,8 @@ class VoucherUseRuleModify(object):
         if not d:
             return None
         o = VoucherUseRuleModify()
+        if 'exchange_voucher' in d:
+            o.exchange_voucher = d['exchange_voucher']
         if 'voucher_valid_period' in d:
             o.voucher_valid_period = d['voucher_valid_period']
         return o
